package zero1hd.polyjet.entity.enemies;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.math.Rectangle;
import com.badlogic.gdx.math.Vector2;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.utils.Pool.Poolable;

import zero1hd.polyjet.Polyjet;
import zero1hd.polyjet.entity.Entities;
import zero1hd.polyjet.entity.Entity;

public class Pellet extends Actor implements Entity, Poolable {
	private boolean dead;
	private Texture texture;
	private Rectangle hitBox;
	private Vector2 direction;
	private float rate;
	
	public Pellet(Texture texture) {
		hitBox = new Rectangle();
		direction = new Vector2();
		this.texture = texture;
	}
	
	public void init(float x, float y, float direction, float rate) {
		setPosition(x, y);
		this.direction.setAngle(direction);
		rate = 0;
		setSize(0.5f, 0.5f);
	}
	
	@Override
	public void act(float delta) {
		moveBy(direction.x*delta*rate, direction.y*delta*rate);
		super.act(delta);
		
		if (getX() > Polyjet.GAME_AREA_WIDTH || getY() > Polyjet.GAME_AREA_HEIGHT || getX()-getWidth() < 0 || getY()-getHeight() < 0) {
			dead = true;
		}
	}
	
	@Override
	public void draw(Batch batch, float parentAlpha) {
		batch.draw(texture, getX(), getY(), getWidth(), getHeight());
		super.draw(batch, parentAlpha);
	}
	
	@Override
	public void collided(Entity entity) {
		if (entity.getEntityType() == Entities.VOID_CIRCLE) {
			dead = true;
		}
	}

	@Override
	public Rectangle getHitZone() {
		return hitBox;
	}

	@Override
	public Entities getEntityType() {
		return Entities.PELLET;
	}

	@Override
	public boolean isDead() {
		return dead;
	}

	@Override
	public void reset() {
		hitBox.set(0, 0, 0, 0);
		setSize(0, 0);
		setPosition(0, 0);
		direction.set(0,0);
		rate = 0;
	}

}
